.. SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases.segment.drishtigs1:

=============
 DRISHTI-GS1
=============

* DataModule and support code: :py:mod:`.data.segment.drishtigs1`
* Splits:

  .. list-table::
     :align: left

     * - Config. key
       - Module
     * - ``drishtigs1-disc-all``
       - :py:mod:`.config.segment.data.drishtigs1.optic_disc_all`
     * - ``drishtigs1-disc-any``
       - :py:mod:`.config.segment.data.drishtigs1.optic_disc_any`
     * - ``drishtigs1-cup-all``
       - :py:mod:`.config.segment.data.drishtigs1.optic_cup_all`
     * - ``drishtigs1-cup-any``
       - :py:mod:`.config.segment.data.drishtigs1.optic_cup_any`
